@@ -33,42 +33,42 @@ COL_FUNC_MANY_MAP = {
 
 T = RedData | MilData | BlueData | GrowthData
 
-async def generate_data(col: str, target: str, client: AsyncIOMotorClient) -> T:
+async def generate_data(col: str, target: str) -> T:
     generator = GENERATOR_MAP.get(col)
     if not generator:
         raise ValueError(f"지원하지 않는 컬렉션: {col}")
-    data = await generator(target, client)
+    data = await generator(target)
     pretty_print(data)
     return data
 
 
-async def save_data(col: str, data: T, client: AsyncIOMotorClient):
+async def save_data(col: str, data: T):
     func = COL_FUNC_MAP.get(col)
     if not func:
         raise ValueError(f"저장 함수 없음: {col}")
 
-    result = await func(data, client)
+    result = await func(data)
     print(result)
 
 
-async def generate_many_data(col: str, targets: list[str], client: AsyncIOMotorClient) -> dict[str, T]:
+async def generate_many_data(col: str, targets: list[str]) -> dict[str, T]:
     generator = GENERATOR_MAP.get(col)
     if not generator:
         raise ValueError(f"지원하지 않는 컬렉션: {col}")
 
     results = {}
     for target in targets:
-        results[target] = await generator(target, client)
+        results[target] = await generator(target)
 
     pretty_print(results)
     return results
 
 
-async def save_many_data(col: str, many_data: dict[str, T], client: AsyncIOMotorClient):
+async def save_many_data(col: str, many_data: dict[str, T]):
     func = COL_FUNC_MANY_MAP.get(col)
     if not func:
         raise ValueError(f"저장 함수 없음: {col}")
-    result = await func(many_data, client)
+    result = await func(many_data)
     print(result)
 
 
@@ -78,14 +78,10 @@ def handle_save_many_command(col: str, targets: list[str]):
         print("유효한 종목 코드가 없습니다.")
         return
 
-    client = connection.get_mongo_client()
-
     async def main():
-        try:
-            many_data = await generate_many_data(col, valid_targets, client)
-            await save_many_data(col, many_data, client)
-        finally:
-            client.close()
+        many_data = await generate_many_data(col, valid_targets)
+        await save_many_data(col, many_data)
+
 
     asyncio.run(main())
 
@@ -95,14 +91,9 @@ def handle_save_command(col: str, target: str):
         print(f"잘못된 코드: {target}")
         return
 
-    client = connection.get_mongo_client()
-
     async def main():
-        try:
-            data = await generate_data(col, target, client)
-            await save_data(col, data, client)
-        finally:
-            client.close()
+        data = await generate_data(col, target)
+        await save_data(col, data)
 
     asyncio.run(main())
 
